[Zope-Checkins] SVN: Zope/branches/console-scripts/ another approach for generating the console scripts through entry points

2009-02-19 Thread Andreas Jung
Log message for revision 96736:
  another approach for generating the console scripts through entry points
  

Changed:
  A   Zope/branches/console-scripts/

-=-
___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/ updated

2009-02-19 Thread Andreas Jung
Log message for revision 96737:
  updated
  

Changed:
  U   Zope/branches/console-scripts/setup.py
  A   Zope/branches/console-scripts/src/utilities/
  D   Zope/branches/console-scripts/utilities/

-=-
Modified: Zope/branches/console-scripts/setup.py
===
--- Zope/branches/console-scripts/setup.py  2009-02-19 12:39:27 UTC (rev 
96736)
+++ Zope/branches/console-scripts/setup.py  2009-02-19 12:46:00 UTC (rev 
96737)
@@ -261,4 +261,9 @@
 
   include_package_data=True,
   zip_safe=False,
+  entry_points={
+ 'console_scripts' : [
+'mkzopeinstance=utilities.mkzopeinstance:main',
+]
+  },
   )


Property changes on: Zope/branches/console-scripts/src/utilities
___
Added: svn:externals
   + ZODBTools svn://svn.zope.org/repos/main/ZODB/tags/3.9.0a10/src/ZODB/scripts

Added: svn:mergeinfo
   + 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/setup.py added zpasswd

2009-02-19 Thread Andreas Jung
Log message for revision 96738:
  added zpasswd
  

Changed:
  U   Zope/branches/console-scripts/setup.py

-=-
Modified: Zope/branches/console-scripts/setup.py
===
--- Zope/branches/console-scripts/setup.py  2009-02-19 12:46:00 UTC (rev 
96737)
+++ Zope/branches/console-scripts/setup.py  2009-02-19 12:48:35 UTC (rev 
96738)
@@ -264,6 +264,7 @@
   entry_points={
  'console_scripts' : [
 'mkzopeinstance=utilities.mkzopeinstance:main',
+'zpasswd=utilities.zpasswd:main',
 ]
   },
   )

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/versions-zope2.cfg ZODB3 a11 is out

2009-02-19 Thread Hanno Schlichting
Log message for revision 96739:
  ZODB3 a11 is out
  

Changed:
  U   Zope/trunk/versions-zope2.cfg

-=-
Modified: Zope/trunk/versions-zope2.cfg
===
--- Zope/trunk/versions-zope2.cfg   2009-02-19 12:48:35 UTC (rev 96738)
+++ Zope/trunk/versions-zope2.cfg   2009-02-19 12:49:27 UTC (rev 96739)
@@ -12,6 +12,7 @@
 RestrictedPython = 3.5.0
 tempstorage = 2.11.1
 zLOG = 2.11.1
+ZODB3 = 3.9.0a11
 zc.lockfile = 1.0
 transaction = 1.0a1
 zope.broken = 3.5.0

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/src/ moved utilities to Zope2

2009-02-19 Thread Andreas Jung
Log message for revision 96740:
  moved utilities to Zope2
  

Changed:
  A   Zope/branches/console-scripts/src/Zope2/utilities/
  D   Zope/branches/console-scripts/src/utilities/

-=-
___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/setup.py checkpoint for further testing

2009-02-19 Thread Andreas Jung
Log message for revision 96741:
  checkpoint for further testing
  

Changed:
  U   Zope/branches/console-scripts/setup.py

-=-
Modified: Zope/branches/console-scripts/setup.py
===
--- Zope/branches/console-scripts/setup.py  2009-02-19 12:53:36 UTC (rev 
96740)
+++ Zope/branches/console-scripts/setup.py  2009-02-19 12:55:08 UTC (rev 
96741)
@@ -263,8 +263,8 @@
   zip_safe=False,
   entry_points={
  'console_scripts' : [
-'mkzopeinstance=utilities.mkzopeinstance:main',
-'zpasswd=utilities.zpasswd:main',
+'mkzopeinstance=Zope2.utilities.mkzopeinstance:main',
+'zpasswd=Zope2.utilities.zpasswd:main',
 ]
   },
   )

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/ Reformat the changelog and include it into the long description

2009-02-19 Thread Hanno Schlichting
Log message for revision 96742:
  Reformat the changelog and include it into the long description
  

Changed:
  U   Zope/trunk/doc/CHANGES.txt
  U   Zope/trunk/setup.py

-=-
Modified: Zope/trunk/doc/CHANGES.txt
===
--- Zope/trunk/doc/CHANGES.txt  2009-02-19 12:55:08 UTC (rev 96741)
+++ Zope/trunk/doc/CHANGES.txt  2009-02-19 13:00:24 UTC (rev 96742)
@@ -1,220 +1,226 @@
-Zope Changes
+Changelog
+=
 
-  This file contains change information for the current Zope release.
-  Change information for previous versions of Zope can be found in the
-  file HISTORY.txt.
+This file contains change information for the current Zope release.
+Change information for previous versions of Zope can be found in the
+file HISTORY.txt.
 
-  Trunk (unreleased)
+Trunk (unreleased)
+--
 
-Restructuring
+Restructuring
++
 
-  - Updated to ZODB 3.9.0a10. ZODB-level version support has been
-removed and ZopeUndo now is part of Zope2.
+- Updated to ZODB 3.9.0a10. ZODB-level version support has been
+  removed and ZopeUndo now is part of Zope2.
 
-  - The Zope2 SVN trunk is now a buildout pulling in all dependencies as
-actual released packages and not SVN externals anymore.
+- The Zope2 SVN trunk is now a buildout pulling in all dependencies as
+  actual released packages and not SVN externals anymore.
 
-  - Make use of the new zope.container and zope.site packages.
+- Make use of the new zope.container and zope.site packages.
 
-  - Updated to newer versions of zope packages. Removed long deprecated
-layer and skin ZCML directives.
+- Updated to newer versions of zope packages. Removed long deprecated
+  layer and skin ZCML directives.
 
-  - Disabled the XML export on the UI level - the export functionality
-however is still available on the Python level.
+- Disabled the XML export on the UI level - the export functionality
+  however is still available on the Python level.
 
-  - No longer show the Help! links in the ZMI, if there is no help
-available. The help system depends on the product registry.
+- No longer show the Help! links in the ZMI, if there is no help
+  available. The help system depends on the product registry.
 
-  - Updated the quick start page and simplified the standard content.
-The default index_html is now a page template.
+- Updated the quick start page and simplified the standard content.
+  The default index_html is now a page template.
 
-  - Removed deprecated Draft and Version support from Products.OFSP.
-Also removed version handling from the control panel. Versions are
-no longer supported on the ZODB level.
+- Removed deprecated Draft and Version support from Products.OFSP.
+  Also removed version handling from the control panel. Versions are
+  no longer supported on the ZODB level.
 
-  - Removed left-overs of the deprecated persistent product distribution
-mechanism.
+- Removed left-overs of the deprecated persistent product distribution
+  mechanism.
 
-  - The persistent product registry is not required for starting Zope
-anymore. `enable-product-installation` can be set to off if you don't
-rely on the functionality provided by the registry.
+- The persistent product registry is not required for starting Zope
+  anymore. `enable-product-installation` can be set to off if you don't
+  rely on the functionality provided by the registry.
 
-  - ZClasses have been deprecated for two major releases. They have been
-removed in this version of Zope.
+- ZClasses have been deprecated for two major releases. They have been
+  removed in this version of Zope.
 
-  - Avoid deprecation warnings for the md5 and sha modules in Python 2.6
-by adding conditional imports for the hashlib module.
+- Avoid deprecation warnings for the md5 and sha modules in Python 2.6
+  by adding conditional imports for the hashlib module.
 
-  - Replaced imports from the 'Globals' module throughout the 
-tree with imports from the actual modules;  the 'Globals' module
-was always intended to be an area for shared data, rather than
-a "facade" for imports.  Added zope.deferred.deprecation entries
-to 'Globals' for all symbols / modules previously imported directly.
+- Replaced imports from the 'Globals' module throughout the 
+  tree with imports from the actual modules;  the 'Globals' module
+  was always intended to be an area for shared data, rather than
+  a "facade" for imports.  Added zope.deferred.deprecation entries
+  to 'Globals' for all symbols / modules previously imported directly.
 
-  - Protect against non-existing zope.conf path and products directories.
-This makes it possible to run a Zope instance without a Products or
-lib/python directory.
+- Protect against non-existing zope.conf path and products dir

[Zope-Checkins] SVN: Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py fixed detection of zopeskelsrc

2009-02-19 Thread Andreas Jung
Log message for revision 96743:
  fixed detection of zopeskelsrc
  

Changed:
  U   Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py

-=-
Modified: Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py
===
--- Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py 
2009-02-19 13:00:24 UTC (rev 96742)
+++ Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py 
2009-02-19 13:11:26 UTC (rev 96743)
@@ -86,7 +86,9 @@
 configfile = os.path.join(instancehome, 'etc', 'zope.conf')
 if skelsrc is None:
 # default to using stock Zope skeleton source
-skelsrc = os.path.join(zopehome, "skel")
+#skelsrc = os.path.join(zopehome, "skel")
+# 'utilites' dir moved to Zope2.utilities
+skelsrc = os.path.join(zopehome, "..", "..", "skel")
 
 inituser = os.path.join(instancehome, "inituser")
 if not (user or os.path.exists(inituser)):

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/src/Zope2/utilities/instance.py added for testing (from Repoze)

2009-02-19 Thread Andreas Jung
Log message for revision 96744:
  added for testing (from Repoze)
  

Changed:
  A   Zope/branches/console-scripts/src/Zope2/utilities/instance.py

-=-
Added: Zope/branches/console-scripts/src/Zope2/utilities/instance.py
===
--- Zope/branches/console-scripts/src/Zope2/utilities/instance.py   
(rev 0)
+++ Zope/branches/console-scripts/src/Zope2/utilities/instance.py   
2009-02-19 13:15:28 UTC (rev 96744)
@@ -0,0 +1,86 @@
+import optparse
+import os
+import os.path
+import sys
+import re
+
+here = os.path.abspath(os.path.dirname(__file__))
+
+# I would use string.Template, but it's just too hard to change it to
+# respect only ${brace} syntax instead of both that and $name syntax.
+TOKEN_RE = re.compile(r'\$\{([\.\w/-]+)\}')
+def rewrite(repltext, **kw):
+def replace(match):
+return kw[match.group(1)]
+return TOKEN_RE.sub(replace, repltext)
+
+def mkinstance(conf):
+sandbox = conf['sandbox']
+
+for dir in ('bin', 'etc', 'var', 'Products', 'import', 'log'):
+path = os.path.join(sandbox, dir)
+if not os.path.exists(path):
+os.makedirs(path)
+
+try:
+# this is (stupidly) required by the zdrun key in the 
+# section of zeo.conf
+import zdaemon
+conf['zdaemon_pkgdir'] = zdaemon.__path__[0]
+except ImportError:
+conf['zdaemon_pkgdir'] = '{unknown}'
+
+zope_conf = conf['zope_conf']
+site_zcml = conf['site_zcml']
+
+for source, target in (
+('zope2.ini', 'zope2.ini'),
+(site_zcml, 'site.zcml'),
+(zope_conf, 'zope.conf'),
+('apache2.conf', 'apache2.conf'),
+('zeo.conf', 'zeo.conf'),
+):
+template = open(os.path.join(here, 'etc', source), 'r').read()
+result = rewrite(template, **conf)
+targetfile = os.path.join(sandbox, 'etc', target)
+if not os.path.exists(targetfile):
+open(targetfile, 'w').write(result)
+
+template = open(os.path.join(here, 'etc', 'zope2.wsgi'), 'r').read()
+result = rewrite(template, **conf)
+targetfile = os.path.join(sandbox, 'bin', 'zope2.wsgi')
+if not os.path.exists(targetfile):
+open(targetfile, 'w').write(result)
+os.chmod(targetfile, 0755)
+
+def main(argv=sys.argv):
+""" Console script target """
+parser = optparse.OptionParser(
+usage='%prog [OPTIONS]'
+)
+parser.add_option('-s', '--sandbox', action='store', dest='sandbox',
+  default='.', help='Create the instance in this 
directory')
+parser.add_option('-p', '--zope-port', action='store', dest='zope_port',
+  default='8080', help='Zope HTTP port')
+parser.add_option('-j', '--zeo-port', action='store', dest='zeo_port',
+  default='8100', help='ZEO server port number')
+parser.add_option('-z', '--use-zeo', action='store_true', dest='use_zeo',
+  default=False, help='Use ZEO to house main storage')
+options, args = parser.parse_args(argv)
+try:
+# Zope 2.10+ (Five 1.5.3?+)
+from Products.Five.fivedirectives import IRegisterPackageDirective
+options.site_zcml = 'zope-2.10+-site.zcml'
+except ImportError:
+# Zope 2.9 (or Five before 1.5.3?)
+options.site_zcml = 'zope-2.9-site.zcml'
+if options.use_zeo:
+options.zope_conf = 'zope-zeoclient.conf'
+else:
+options.zope_conf = 'zope-nonzeoclient.conf'
+options.python = sys.executable
+conf = options.__dict__
+sandbox = conf['sandbox']
+conf['sandbox'] = os.path.abspath(os.path.normpath(os.path.expanduser(
+sandbox)))
+mkinstance(conf)

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/s moved zopeskel to Zope2.utitilites

2009-02-19 Thread Andreas Jung
Log message for revision 96745:
  moved zopeskel to Zope2.utitilites
  

Changed:
  D   Zope/branches/console-scripts/skel/
  U   Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py
  A   Zope/branches/console-scripts/src/Zope2/utilities/skel/

-=-
Modified: Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py
===
--- Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py 
2009-02-19 13:15:28 UTC (rev 96744)
+++ Zope/branches/console-scripts/src/Zope2/utilities/mkzopeinstance.py 
2009-02-19 13:18:25 UTC (rev 96745)
@@ -86,9 +86,7 @@
 configfile = os.path.join(instancehome, 'etc', 'zope.conf')
 if skelsrc is None:
 # default to using stock Zope skeleton source
-#skelsrc = os.path.join(zopehome, "skel")
-# 'utilites' dir moved to Zope2.utilities
-skelsrc = os.path.join(zopehome, "..", "..", "skel")
+skelsrc = os.path.join(os.path.dirname(__file__), "skel")
 
 inituser = os.path.join(instancehome, "inituser")
 if not (user or os.path.exists(inituser)):


Property changes on: Zope/branches/console-scripts/src/Zope2/utilities/skel
___
Added: svn:mergeinfo
   + 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/setup.py omit data_files

2009-02-19 Thread Andreas Jung
Log message for revision 96747:
  omit data_files
  

Changed:
  U   Zope/branches/console-scripts/setup.py

-=-
Modified: Zope/branches/console-scripts/setup.py
===
--- Zope/branches/console-scripts/setup.py  2009-02-19 13:27:55 UTC (rev 
96746)
+++ Zope/branches/console-scripts/setup.py  2009-02-19 13:34:12 UTC (rev 
96747)
@@ -44,29 +44,29 @@
   packages=find_packages('src'),
   package_dir={'': 'src'},
 
-  data_files=[
-('skel', ['skel/README.txt']),
-('skel/bin', ['skel/bin/runzope.bat.in',
-  'skel/bin/runzope.in',
-  'skel/bin/zopectl.bat.in',
-  'skel/bin/zopectl.in',
-  'skel/bin/zopeservice.py.in',
- ]),
-('skel/etc', ['skel/etc/site.zcml',
-  'skel/etc/zope.conf.in',
- ]),
-('skel/etc/package-includes', []),
-('skel/Extensions', ['skel/Extensions/README.txt']),
-('skel/import', ['skel/import/README.txt',
- 'skel/import/ZopeTutorialExamples.zexp',
-]),
-('skel/lib/python', ['skel/lib/python/README.txt.in' ]),
-('skel/log', ['skel/log/README.txt']),
-('skel/Products', ['skel/Products/__init__.py',
-   'skel/Products/README.txt',
-  ]),
-('skel/var', ['skel/var/README.txt']),
-  ],
+#  data_files=[
+#('skel', ['skel/README.txt']),
+#('skel/bin', ['skel/bin/runzope.bat.in',
+#  'skel/bin/runzope.in',
+#  'skel/bin/zopectl.bat.in',
+#  'skel/bin/zopectl.in',
+#  'skel/bin/zopeservice.py.in',
+# ]),
+#('skel/etc', ['skel/etc/site.zcml',
+#  'skel/etc/zope.conf.in',
+# ]),
+#('skel/etc/package-includes', []),
+#('skel/Extensions', ['skel/Extensions/README.txt']),
+#('skel/import', ['skel/import/README.txt',
+# 'skel/import/ZopeTutorialExamples.zexp',
+#]),
+#('skel/lib/python', ['skel/lib/python/README.txt.in' ]),
+#('skel/log', ['skel/log/README.txt']),
+#('skel/Products', ['skel/Products/__init__.py',
+#   'skel/Products/README.txt',
+#  ]),
+#('skel/var', ['skel/var/README.txt']),
+#  ],
 
   ext_modules=[
 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/setup.py remove data_files

2009-02-19 Thread Andreas Jung
Log message for revision 96748:
  remove data_files
  

Changed:
  U   Zope/branches/console-scripts/setup.py

-=-
Modified: Zope/branches/console-scripts/setup.py
===
--- Zope/branches/console-scripts/setup.py  2009-02-19 13:34:12 UTC (rev 
96747)
+++ Zope/branches/console-scripts/setup.py  2009-02-19 13:43:22 UTC (rev 
96748)
@@ -44,30 +44,6 @@
   packages=find_packages('src'),
   package_dir={'': 'src'},
 
-#  data_files=[
-#('skel', ['skel/README.txt']),
-#('skel/bin', ['skel/bin/runzope.bat.in',
-#  'skel/bin/runzope.in',
-#  'skel/bin/zopectl.bat.in',
-#  'skel/bin/zopectl.in',
-#  'skel/bin/zopeservice.py.in',
-# ]),
-#('skel/etc', ['skel/etc/site.zcml',
-#  'skel/etc/zope.conf.in',
-# ]),
-#('skel/etc/package-includes', []),
-#('skel/Extensions', ['skel/Extensions/README.txt']),
-#('skel/import', ['skel/import/README.txt',
-# 'skel/import/ZopeTutorialExamples.zexp',
-#]),
-#('skel/lib/python', ['skel/lib/python/README.txt.in' ]),
-#('skel/log', ['skel/log/README.txt']),
-#('skel/Products', ['skel/Products/__init__.py',
-#   'skel/Products/README.txt',
-#  ]),
-#('skel/var', ['skel/var/README.txt']),
-#  ],
-
   ext_modules=[
 
 # AccessControl

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/ auto-detect path to Zope2-egg

2009-02-19 Thread Andreas Jung
Log message for revision 96749:
  auto-detect path to Zope2-egg
  

Changed:
  U   Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/runzope.in
  U   Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/zopectl.in

-=-
Modified: Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/runzope.in
===
--- Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/runzope.in   
2009-02-19 13:43:22 UTC (rev 96748)
+++ Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/runzope.in   
2009-02-19 14:03:12 UTC (rev 96749)
@@ -8,6 +8,7 @@
 PYTHONPATH="$SOFTWARE_HOME:$PYTHONPATH"
 export PYTHONPATH INSTANCE_HOME SOFTWARE_HOME
 
-ZOPE_RUN="$SOFTWARE_HOME/Zope2/Startup/run.py"
+ZOPE2PATH=`${PYTHON} -c "import os, Zope2; print 
os.path.dirname(Zope2.__file__)" `
+ZOPE_RUN="$ZOPE2PATH/Startup/run.py"
 
 exec "$PYTHON" "$ZOPE_RUN" -C "$CONFIG_FILE" "$@"

Modified: Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/zopectl.in
===
--- Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/zopectl.in   
2009-02-19 13:43:22 UTC (rev 96748)
+++ Zope/branches/console-scripts/src/Zope2/utilities/skel/bin/zopectl.in   
2009-02-19 14:03:12 UTC (rev 96749)
@@ -8,6 +8,7 @@
 PYTHONPATH="$SOFTWARE_HOME:$PYTHONPATH"
 export PYTHONPATH INSTANCE_HOME SOFTWARE_HOME
 
-ZDCTL="$SOFTWARE_HOME/Zope2/Startup/zopectl.py"
+ZOPE2PATH=`${PYTHON} -c "import os, Zope2; print 
os.path.dirname(Zope2.__file__)" `
+ZDCTL="$ZOPE2PATH/Startup/zopectl.py"
 
 exec "$PYTHON" "$ZDCTL" -C "$CONFIG_FILE" "$@"

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/tags/before-merging-console-scripts-branch/ 'creating tag svn+ssh://andreasj...@svn.zope.org/repos/main/Zope/tags/before-merging-console-scripts-branch from svn+ssh://andreas

2009-02-19 Thread Andreas Jung
Log message for revision 96750:
  'creating tag 
svn+ssh://andreasj...@svn.zope.org/repos/main/Zope/tags/before-merging-console-scripts-branch
 from svn+ssh://andreasj...@svn.zope.org/repos/main/Zope/trunk'

Changed:
  A   Zope/tags/before-merging-console-scripts-branch/

-=-
___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/s merged console-scripts branch

2009-02-19 Thread Andreas Jung
Log message for revision 96751:
  merged console-scripts branch
  

Changed:
  U   Zope/trunk/setup.py
  D   Zope/trunk/skel/
  A   Zope/trunk/src/Zope2/utilities/
  _U  Zope/trunk/src/Zope2/utilities/skel/

-=-
Modified: Zope/trunk/setup.py
===
--- Zope/trunk/setup.py 2009-02-19 14:23:44 UTC (rev 96750)
+++ Zope/trunk/setup.py 2009-02-19 14:24:28 UTC (rev 96751)
@@ -48,30 +48,6 @@
   packages=find_packages('src'),
   package_dir={'': 'src'},
 
-  data_files=[
-('skel', ['skel/README.txt']),
-('skel/bin', ['skel/bin/runzope.bat.in',
-  'skel/bin/runzope.in',
-  'skel/bin/zopectl.bat.in',
-  'skel/bin/zopectl.in',
-  'skel/bin/zopeservice.py.in',
- ]),
-('skel/etc', ['skel/etc/site.zcml',
-  'skel/etc/zope.conf.in',
- ]),
-('skel/etc/package-includes', []),
-('skel/Extensions', ['skel/Extensions/README.txt']),
-('skel/import', ['skel/import/README.txt',
- 'skel/import/ZopeTutorialExamples.zexp',
-]),
-('skel/lib/python', ['skel/lib/python/README.txt.in' ]),
-('skel/log', ['skel/log/README.txt']),
-('skel/Products', ['skel/Products/__init__.py',
-   'skel/Products/README.txt',
-  ]),
-('skel/var', ['skel/var/README.txt']),
-  ],
-
   ext_modules=[
 
 # AccessControl
@@ -265,4 +241,10 @@
 
   include_package_data=True,
   zip_safe=False,
+  entry_points={
+ 'console_scripts' : [
+'mkzopeinstance=Zope2.utilities.mkzopeinstance:main',
+'zpasswd=Zope2.utilities.zpasswd:main',
+]
+  },
   )


Property changes on: Zope/trunk/src/Zope2/utilities
___
Added: svn:externals
   + ZODBTools svn://svn.zope.org/repos/main/ZODB/tags/3.9.0a10/src/ZODB/scripts

Added: svn:mergeinfo
   + 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/src/Zope2/utilities/copyzopeskel.py added code to fix the permission of the generated files in 'bin'

2009-02-19 Thread Andreas Jung
Log message for revision 96753:
  added code to fix the permission of the generated files in 'bin'
  

Changed:
  U   Zope/trunk/src/Zope2/utilities/copyzopeskel.py

-=-
Modified: Zope/trunk/src/Zope2/utilities/copyzopeskel.py
===
--- Zope/trunk/src/Zope2/utilities/copyzopeskel.py  2009-02-19 14:25:55 UTC 
(rev 96752)
+++ Zope/trunk/src/Zope2/utilities/copyzopeskel.py  2009-02-19 14:41:21 UTC 
(rev 96753)
@@ -186,6 +186,13 @@
 print >>sys.stderr, msg
 sys.exit(1)
 
+# fix permission in 'bin' directory
+bin_dir = os.path.join(targetdir, 'bin')
+for fname in os.listdir(bin_dir):
+fullname = os.path.join(bin_dir, fname)
+os.chmod(fullname, 0700)
+
+
 CVS_DIRS = [os.path.normcase("CVS"), os.path.normcase(".svn")]
 
 def copydir((targetdir, replacements, uid, gid), sourcedir, names):

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/setup.py dupe long_description parameter

2009-02-19 Thread Andreas Jung
Log message for revision 96752:
  dupe long_description parameter
  

Changed:
  U   Zope/trunk/setup.py

-=-
Modified: Zope/trunk/setup.py
===
--- Zope/trunk/buildout.cfg 2009-02-19 14:55:48 UTC (rev 96754)
+++ Zope/trunk/buildout.cfg 2009-02-19 14:58:34 UTC (rev 96755)
@@ -21,22 +21,6 @@
 ZOPE_HOME = ${buildout:directory}
 INSTANCE_HOME = ${buildout:directory}
 
-[omelette]
-recipe = collective.recipe.omelette >= 0.7
-eggs = ${buildout:eggs}
-
-[lib_python]
-recipe = z3c.recipe.runscript
-install-script = bin/create_lib_python.py:create_lib_python
-update-script = bin/create_lib_python.py:create_lib_python
-src-dir = ${omelette:location}
-dst-dir = ${buildout:directory}/lib/python
-skip-names =
-easy_install.py
-pkg_resources.py
-setuptools
-site.py
-
 [zopepy]
 recipe = zc.recipe.egg
 eggs = ${buildout:eggs}

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/b Removed the bin folder, as we don't use the create_lib_python script. Beware SVN will annoy you!

2009-02-19 Thread Hanno Schlichting
Log message for revision 96756:
  Removed the bin folder, as we don't use the create_lib_python script. Beware 
SVN will annoy you!
  

Changed:
  D   Zope/trunk/bin/
  U   Zope/trunk/buildout.cfg

-=-
Modified: Zope/trunk/buildout.cfg
===
--- Zope/trunk/buildout.cfg 2009-02-19 14:58:34 UTC (rev 96755)
+++ Zope/trunk/buildout.cfg 2009-02-19 15:06:31 UTC (rev 96756)
@@ -3,6 +3,7 @@
 .
 parts =
 test
+scripts
 zopepy
 
 extends = versions-zope2.cfg
@@ -21,6 +22,10 @@
 ZOPE_HOME = ${buildout:directory}
 INSTANCE_HOME = ${buildout:directory}
 
+[scripts]
+recipe = zc.recipe.egg:scripts
+eggs = Zope2
+
 [zopepy]
 recipe = zc.recipe.egg
 eggs = ${buildout:eggs}

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/src/Zope2/utilities/instance.py re-removed repoze' instance.py

2009-02-19 Thread Andreas Jung
Log message for revision 96757:
  re-removed repoze' instance.py
  

Changed:
  D   Zope/trunk/src/Zope2/utilities/instance.py

-=-
Deleted: Zope/trunk/src/Zope2/utilities/instance.py
===
--- Zope/trunk/src/Zope2/utilities/instance.py  2009-02-19 15:06:31 UTC (rev 
96756)
+++ Zope/trunk/src/Zope2/utilities/instance.py  2009-02-19 15:08:03 UTC (rev 
96757)
@@ -1,86 +0,0 @@
-import optparse
-import os
-import os.path
-import sys
-import re
-
-here = os.path.abspath(os.path.dirname(__file__))
-
-# I would use string.Template, but it's just too hard to change it to
-# respect only ${brace} syntax instead of both that and $name syntax.
-TOKEN_RE = re.compile(r'\$\{([\.\w/-]+)\}')
-def rewrite(repltext, **kw):
-def replace(match):
-return kw[match.group(1)]
-return TOKEN_RE.sub(replace, repltext)
-
-def mkinstance(conf):
-sandbox = conf['sandbox']
-
-for dir in ('bin', 'etc', 'var', 'Products', 'import', 'log'):
-path = os.path.join(sandbox, dir)
-if not os.path.exists(path):
-os.makedirs(path)
-
-try:
-# this is (stupidly) required by the zdrun key in the 
-# section of zeo.conf
-import zdaemon
-conf['zdaemon_pkgdir'] = zdaemon.__path__[0]
-except ImportError:
-conf['zdaemon_pkgdir'] = '{unknown}'
-
-zope_conf = conf['zope_conf']
-site_zcml = conf['site_zcml']
-
-for source, target in (
-('zope2.ini', 'zope2.ini'),
-(site_zcml, 'site.zcml'),
-(zope_conf, 'zope.conf'),
-('apache2.conf', 'apache2.conf'),
-('zeo.conf', 'zeo.conf'),
-):
-template = open(os.path.join(here, 'etc', source), 'r').read()
-result = rewrite(template, **conf)
-targetfile = os.path.join(sandbox, 'etc', target)
-if not os.path.exists(targetfile):
-open(targetfile, 'w').write(result)
-
-template = open(os.path.join(here, 'etc', 'zope2.wsgi'), 'r').read()
-result = rewrite(template, **conf)
-targetfile = os.path.join(sandbox, 'bin', 'zope2.wsgi')
-if not os.path.exists(targetfile):
-open(targetfile, 'w').write(result)
-os.chmod(targetfile, 0755)
-
-def main(argv=sys.argv):
-""" Console script target """
-parser = optparse.OptionParser(
-usage='%prog [OPTIONS]'
-)
-parser.add_option('-s', '--sandbox', action='store', dest='sandbox',
-  default='.', help='Create the instance in this 
directory')
-parser.add_option('-p', '--zope-port', action='store', dest='zope_port',
-  default='8080', help='Zope HTTP port')
-parser.add_option('-j', '--zeo-port', action='store', dest='zeo_port',
-  default='8100', help='ZEO server port number')
-parser.add_option('-z', '--use-zeo', action='store_true', dest='use_zeo',
-  default=False, help='Use ZEO to house main storage')
-options, args = parser.parse_args(argv)
-try:
-# Zope 2.10+ (Five 1.5.3?+)
-from Products.Five.fivedirectives import IRegisterPackageDirective
-options.site_zcml = 'zope-2.10+-site.zcml'
-except ImportError:
-# Zope 2.9 (or Five before 1.5.3?)
-options.site_zcml = 'zope-2.9-site.zcml'
-if options.use_zeo:
-options.zope_conf = 'zope-zeoclient.conf'
-else:
-options.zope_conf = 'zope-nonzeoclient.conf'
-options.python = sys.executable
-conf = options.__dict__
-sandbox = conf['sandbox']
-conf['sandbox'] = os.path.abspath(os.path.normpath(os.path.expanduser(
-sandbox)))
-mkinstance(conf)

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/src/Zope2/utilities/ No need to include zodb tools here

2009-02-19 Thread Hanno Schlichting
Log message for revision 96758:
  No need to include zodb tools here
  

Changed:
  _U  Zope/trunk/src/Zope2/utilities/

-=-

Property changes on: Zope/trunk/src/Zope2/utilities
___
Deleted: svn:externals
   - ZODBTools svn://svn.zope.org/repos/main/ZODB/tags/3.9.0a10/src/ZODB/scripts


___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/lib/ No need for lib in svn either

2009-02-19 Thread Hanno Schlichting
Log message for revision 96759:
  No need for lib in svn either
  

Changed:
  D   Zope/trunk/lib/

-=-
___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/utilities/ No need for top-level utilities anymore, they are inside the Zope2 package now

2009-02-19 Thread Hanno Schlichting
Log message for revision 96760:
  No need for top-level utilities anymore, they are inside the Zope2 package 
now 
  

Changed:
  D   Zope/trunk/utilities/

-=-
___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/ Ignore lib

2009-02-19 Thread Hanno Schlichting
Log message for revision 96761:
  Ignore lib
  

Changed:
  _U  Zope/trunk/

-=-

Property changes on: Zope/trunk
___
Modified: svn:ignore
   - access
bin
build
import
include
inituser
ZODBTests.fs*
makefile
Products
etc
log
build-base
testing.log
var
develop-eggs
eggs
parts
.installed.cfg

   + access
bin
build
import
include
inituser
ZODBTests.fs*
makefile
Products
etc
lib
log
build-base
testing.log
var
develop-eggs
eggs
parts
.installed.cfg


___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/ Externals for C headers stink

2009-02-19 Thread Hanno Schlichting
Log message for revision 96762:
  Externals for C headers stink
  

Changed:
  U   Zope/trunk/doc/INSTALL.txt
  _U  Zope/trunk/include/

-=-
Modified: Zope/trunk/doc/INSTALL.txt
===
--- Zope/trunk/doc/INSTALL.txt  2009-02-19 15:19:46 UTC (rev 96761)
+++ Zope/trunk/doc/INSTALL.txt  2009-02-19 15:35:49 UTC (rev 96762)
@@ -59,7 +59,7 @@
 
 You will be asked to provide a user name and password for an
 administrator's account during ``mkzopeinstance``.  To see the available
-ommand-line options, run the script with the ``--help`` option::
+command-line options, run the script with the ``--help`` option::
 
   $ bin/mkzopeinstance --help
 


Property changes on: Zope/trunk/include
___
Modified: svn:externals
   - Acquisition 
svn://svn.zope.org/repos/main/Acquisition/trunk/src/Acquisition
ExtensionClass  
svn://svn.zope.org/repos/main/ExtensionClass/trunk/src/ExtensionClass
persistent  svn://svn.zope.org/repos/main/ZODB/tags/3.9.0a10/src/persistent

   + Acquisition 
svn://svn.zope.org/repos/main/Acquisition/trunk/src/Acquisition
ExtensionClass  
svn://svn.zope.org/repos/main/ExtensionClass/trunk/src/ExtensionClass
persistent  svn://svn.zope.org/repos/main/ZODB/tags/3.9.0a11/src/persistent


___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/doc/CHANGES.txt ZODB 3.9.0a11

2009-02-19 Thread Andreas Jung
Log message for revision 96763:
  ZODB 3.9.0a11
  

Changed:
  U   Zope/trunk/doc/CHANGES.txt

-=-
Modified: Zope/trunk/doc/CHANGES.txt
===
--- Zope/trunk/doc/CHANGES.txt  2009-02-19 15:35:49 UTC (rev 96762)
+++ Zope/trunk/doc/CHANGES.txt  2009-02-19 15:41:41 UTC (rev 96763)
@@ -11,7 +11,7 @@
 Restructuring
 +
 
-- Updated to ZODB 3.9.0a10. ZODB-level version support has been
+- Updated to ZODB 3.9.0a11. ZODB-level version support has been
   removed and ZopeUndo now is part of Zope2.
 
 - The Zope2 SVN trunk is now a buildout pulling in all dependencies as

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/setup.py added mkzeoinstance

2009-02-19 Thread Andreas Jung
Log message for revision 96766:
  added mkzeoinstance
  

Changed:
  U   Zope/trunk/setup.py

-=-
Modified: Zope/trunk/setup.py
===
--- Zope/trunk/setup.py 2009-02-19 15:54:53 UTC (rev 96765)
+++ Zope/trunk/setup.py 2009-02-19 16:36:36 UTC (rev 96766)
@@ -241,6 +241,7 @@
   zip_safe=False,
   entry_points={
  'console_scripts' : [
+'mkzeoinstance=Zope2.utilities.mkzeoinstance:main',
 'mkzopeinstance=Zope2.utilities.mkzopeinstance:main',
 'zpasswd=Zope2.utilities.zpasswd:main',
 ]

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/src/Zope2/utilities/mkzeoinstance.py added a main() function in order to provide a proper

2009-02-19 Thread Andreas Jung
Log message for revision 96767:
  added a main() function in order to provide a proper
  entry point
  

Changed:
  U   Zope/trunk/src/Zope2/utilities/mkzeoinstance.py

-=-
Modified: Zope/trunk/src/Zope2/utilities/mkzeoinstance.py
===
--- Zope/trunk/src/Zope2/utilities/mkzeoinstance.py 2009-02-19 16:36:36 UTC 
(rev 96766)
+++ Zope/trunk/src/Zope2/utilities/mkzeoinstance.py 2009-02-19 16:42:01 UTC 
(rev 96767)
@@ -25,5 +25,8 @@
 
 from ZEO.mkzeoinst import ZEOInstanceBuilder
 
+def main():
+ZEOInstanceBuilder().run()
+
 if __name__ == "__main__":
-ZEOInstanceBuilder().run()
+main()

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/src/Zope2/utilities/requestprofiler.py provide main()

2009-02-19 Thread Andreas Jung
Log message for revision 96768:
  provide main()
  

Changed:
  U   Zope/trunk/src/Zope2/utilities/requestprofiler.py

-=-
Modified: Zope/trunk/src/Zope2/utilities/requestprofiler.py
===
--- Zope/trunk/src/Zope2/utilities/requestprofiler.py   2009-02-19 16:42:01 UTC 
(rev 96767)
+++ Zope/trunk/src/Zope2/utilities/requestprofiler.py   2009-02-19 16:45:43 UTC 
(rev 96768)
@@ -701,7 +701,7 @@
 return usage
 
 
-if __name__ == '__main__':
+def main():
 if len(sys.argv) == 1:
 print usage()
 sys.exit(0)
@@ -838,3 +838,6 @@
 traceback.print_exc()
 print usage()
 sys.exit(0)
+
+if __name__ == '__main__':
+main()

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/doc/CHANGES.txt Added a couple of known issues

2009-02-19 Thread Hanno Schlichting
Log message for revision 96791:
  Added a couple of known issues
  

Changed:
  U   Zope/trunk/doc/CHANGES.txt

-=-
Modified: Zope/trunk/doc/CHANGES.txt
===
--- Zope/trunk/doc/CHANGES.txt  2009-02-19 17:48:37 UTC (rev 96790)
+++ Zope/trunk/doc/CHANGES.txt  2009-02-19 18:22:25 UTC (rev 96791)
@@ -8,6 +8,18 @@
 Trunk (unreleased)
 --
 
+Known issues
+
+
+- Running Zope on Windows is not yet supported in this alpha release.
+  More specifically the generated startup scripts need to be adjusted,
+  while the code itself should work fine.
+
+- ZODB 3.9.0a11 does not work on Windows with Python 2.6 yet.
+
+- There is no old-style full tarball release that resembles the prior
+  releases of Zope at this point.
+
 Restructuring
 +
 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins
--- Zope/trunk/setup.py 2009-02-19 14:24:28 UTC (rev 96751)
+++ Zope/trunk/setup.py 2009-02-19 14:25:55 UTC (rev 96752)
@@ -40,11 +40,9 @@
   description='Zope2 application server / web framework',
   author='Zope Corporation and Contributors',
   author_email='zope-...@zope.org',
-  long_description=open("README.txt").read() + "\n" +
-   open(os.path.join("doc", "CHANGES.txt")).read(),
+  long_description=file("README.txt").read() + "\n" +
+   file(os.path.join("doc", "CHANGES.txt")).read(),
 
-  long_description='',
-  
   packages=find_packages('src'),
   package_dir={'': 'src'},
 

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/src/Zope2/utilities/copyzopeskel.py wording

2009-02-19 Thread Andreas Jung
Log message for revision 96754:
  wording
  

Changed:
  U   Zope/trunk/src/Zope2/utilities/copyzopeskel.py

-=-
Modified: Zope/trunk/src/Zope2/utilities/copyzopeskel.py
===
--- Zope/trunk/src/Zope2/utilities/copyzopeskel.py  2009-02-19 14:41:21 UTC 
(rev 96753)
+++ Zope/trunk/src/Zope2/utilities/copyzopeskel.py  2009-02-19 14:55:48 UTC 
(rev 96754)
@@ -186,7 +186,7 @@
 print >>sys.stderr, msg
 sys.exit(1)
 
 # fix permission in 'bin' directory
 bin_dir = os.path.join(targetdir, 'bin')
 for fname in os.listdir(bin_dir):
 fullname = os.path.join(bin_dir, fname)

___
Zope-Checkins maillist  -  Zope-Checkins@zope.org
http://mail.zope.org/mailman/listinfo/zope-checkins


[Zope-Checkins] SVN: Zope/trunk/buildout.cfg We don't use the omelette right now, remove!

2009-02-19 Thread Hanno Schlichting
Log message for revision 96755:
  We don't use the omelette right now, remove!
  

Changed:
  U   Zope/trunk/buildout.cfg

-=-
@@ -186,7 +186,7 @@
 sys.exit(1)
 
-# fix permission in 'bin' directory
+# fix file permissions in 'bin' directory
 bin_dir = os.path.join(targetdir, 'bin')
 for fname in os.listdir(bin_dir):
Modified: Zope/trunk/buildout.cfg
===